/*<![CDATA[*/

/**
 * Copyright (c) 2010-2019 V.Krishn (insteps.net)
 *
 * This file is part of Cookbook recipe "QNotes" for PmWiki;
 * See accompanying package for more details.
 * Package: http://insteps.net/pr/a/pmwiki/Apps/Qnotes
 *
 * Presenter for QNotes.
 * Description: A simple presentation / notes-navigator module.
 *
 */


(function( Qnotes, undefined ) {
  var presenter = Qnotes.Presenter = {
    delay: 5000,
    btnsName: [ 'first', 'prev', 'start', 'stop', 'next', 'last', 'repeat' ],
    btn: {},
    first: function () {
      this.show(0);
      return this;
    },
    prev: function () {
      n = 0; if(typeof this.cnum == 'number') { n = this.cnum-2; }
      this.show(n);
      return this;
    },
    start: function () {
      this.play = 1;
      if(this.btn.start.innerHTML == 'Pause') {
        this.clear(1); return;
      } else {
        this.btn.start.innerHTML = 'Pause';
      }
      n = 0; if(typeof this.cnum == 'number') { n = this.cnum-1; }
      this.trigger(n);
      return this;
    },
    stop: function () {
      this.play = 0;
      this.clear(1).first();
      this.cnum = 1;
      setTimeout(function() { Qnotes.ViewBox.hide(); }, 100);
      return this;
    },
    next: function () {
      if(typeof this.cnum != 'number') { this.cnum = 0; }
      this.show(this.cnum);
      return this;
    },
    last: function () {
      n = this.list.length-1;
      this.show(n);
      return this;
    },
    repeat: function () {
      if(this.isRepeat == 1) {
        this.isRepeat = 0; this.btn.repeat.className = '';
      } else {
        this.isRepeat = 1; this.btn.repeat.className = 'repeat';
      }
      return this;
    },
    restart: function () {
      this.stop().start();
      return this;
    },
    show: function (n) {
      if(this.btn.start.innerHTML == 'Pause') {
        this.clear(0); this.trigger(n);
      } else {
        this.trigger(n); this.clear(1);
      }
      return this;
    },
    clear: function (isToggle) {
      if(isToggle === 1) { this.btn.start.innerHTML = 'Start'; }
      if(typeof(countdown) != 'undefined') { clearTimeout(countdown); }
      return this;
    }
    
  }
}( Qnotes ) );

DOMAssistant.Qnotes.Presenter = function () {
  var Init = {
    loading: function () {
      $('#qnotesList1-wrapper').PresenterList();
      $('#qnotes_presenter').PresenterBtns();
      $('#qnotes_presenter_goto').PresenterGoTo();
      $('#qnotes_presenter_progressbar').PresenterProgress();
    },
    eventbtns: function (e) {
      btn = $(e.target).retrieve("navname");
      if(btn != undefined) { Qnotes.Presenter[btn](); }
      return this;
    },
    list: function (e) {
      if(cnum = $(e.target).retrieve("cnum")) {
    Qnotes.Presenter.cnum = cnum; Init.progress(cnum); }
      return this;
    },
    progress: function (cnum) {
      presenter = Qnotes.Presenter;
      var len = presenter.list.length;
      a = cnum; if(a >= len) a = len; if(a <= 1) a = 1;
      presenter.completion = (a/len)*100;
      if(presenter.pb) { presenter.pb.style.width = presenter.completion+'%'; }
      if(presenter.gotoinput) { presenter.gotoinput.value = a; }
    },
    trigger: function (cnum) { //trigger list item
      presenter = Qnotes.Presenter;
      var len = presenter.list.length;

      Init.progress(cnum+1);
      if(cnum <= len) {
        o = presenter.list[cnum];
        if(typeof o == 'undefined') { return; }
        presenter.cnum = cnum; cnum++;
        o.triggerEvent("mousedown"); Qnotes.List.expand0(o); //Qnotes.Event = 'List';
        if(cnum < len) {
          countdown = setTimeout(function() { presenter.trigger(cnum); }, presenter.delay);
        } else {
          if(presenter.play == 1) {
            presenter.start();
            if(presenter.isRepeat == 1) {
             setTimeout(function() { presenter.restart(); }, presenter.delay); }
          }
        }
      }
      return presenter;
    }
  }
  
  return {
    publicMethods : [
      "Presenter", "PresenterList", "PresenterBtns",
      "PresenterGoTo", "PresenterProgress"
    ],
    init : function () {
      if(typeof Qnotes.Ready == 'undefined') { Qnotes.Ready = []; }
      Qnotes.Ready.push(Init.loading);
    },
    Presenter : function () {
      return this;
    },
    PresenterList : function () {
      this.addEvent('mousedown', Init.list);
      Qnotes.Presenter.list = this.elmsByAttribute('class', 'phplm', 'a');
      Qnotes.Presenter.list.each( function(elm, idx, set) {
        $(elm).store("cnum", idx+1);
      });
      return this;
    },
    PresenterBtns : function () {
      Qnotes.Presenter.btns = btns = this.elmsByAttribute('', '', 'a');
      Qnotes.Presenter.trigger = Init.trigger;
      if (btns.length = Qnotes.Presenter.btnsName.length) {
        btns.each( function(elm, idx, set) {
          $(elm).title = nm = Qnotes.Presenter.btnsName[idx];
          $(elm).store("navname", nm);
          Qnotes.Presenter.btn[nm] = elm;
        });
        var countdown;
      }
      this.onclick = function(e) { Init.eventbtns(e); return false; }
      return this;
    },
    PresenterGoTo : function () {
      Qnotes.Presenter.gotofrm = gotofrm = this.elmsByAttribute('', '', 'form').first();
      Qnotes.Presenter.gotoinput = gotoinput = this.elmsByAttribute('', '', 'input').first();
      Qnotes.Presenter.total = total = this.elmsByAttribute('', '', 'span');
      total.first().innerHTML = Qnotes.Presenter.list.length;
      gotofrm.onsubmit = function() {
        if(isNaN(gotoinput.value) == true) { return false; }
        Qnotes.Presenter.show(gotoinput.value-1); return false; }
      return this;
    },
    PresenterProgress : function () {
      Qnotes.Presenter.pbnum = pbnum = this.elmsByAttribute('', '', 'span').first();
      pbnum.innerHTML = Qnotes.Presenter.list.length;
      this.create("div", {'class': "progressbar", 'title': Qnotes.Presenter.list.length }, true, "&nbsp;");
      Qnotes.Presenter.pb = pb = this.elmsByAttribute('', '', 'div').first();
    }
  }
  
}();

DOMAssistant.attach(DOMAssistant.Qnotes.Presenter);
DOMAssistant.harmonize();

/*]]>*/

